@@ -1,38 +1,40 @@
 import os
 import pickle
 import uuid
+from typing import Any, Mapping, Optional
 
 from dagster import (
     AssetMaterialization,
     ExpectationResult,
     Failure,
-    Materialization,
-    ModeDefinition,
-    PipelineDefinition,
-    SolidDefinition,
+    LoggerDefinition,
+    ResourceDefinition,
     TypeCheck,
-    check,
 )
-from dagster.core.definitions.dependency import NodeHandle
-from dagster.core.definitions.events import RetryRequested
-from dagster.core.definitions.pipeline_base import InMemoryPipeline
-from dagster.core.definitions.reconstruct import ReconstructablePipeline
-from dagster.core.definitions.resource_definition import ScopedResourcesBuilder
-from dagster.core.events import DagsterEvent
-from dagster.core.execution.api import scoped_pipeline_context
-from dagster.core.execution.plan.outputs import StepOutputHandle
-from dagster.core.execution.plan.plan import ExecutionPlan
-from dagster.core.execution.resources_init import (
+from dagster import _check as check
+from dagster._core.definitions.dependency import NodeHandle
+from dagster._core.definitions.events import RetryRequested
+from dagster._core.definitions.pipeline_base import InMemoryPipeline
+from dagster._core.definitions.reconstruct import ReconstructablePipeline
+from dagster._core.definitions.resource_definition import ScopedResourcesBuilder
+from dagster._core.errors import DagsterInvariantViolationError
+from dagster._core.events import DagsterEvent
+from dagster._core.execution.api import scoped_pipeline_context
+from dagster._core.execution.plan.outputs import StepOutputHandle
+from dagster._core.execution.plan.plan import ExecutionPlan
+from dagster._core.execution.resources_init import (
     get_required_resource_keys_to_init,
     resource_initialization_event_generator,
 )
-from dagster.core.instance import DagsterInstance
-from dagster.core.storage.pipeline_run import DagsterRun, PipelineRunStatus
-from dagster.core.system_config.objects import ResolvedRunConfig
-from dagster.core.utils import make_new_run_id
-from dagster.loggers import colored_console_logger
-from dagster.serdes import unpack_value
-from dagster.utils import EventGenerationManager, ensure_gen
+from dagster._core.instance import DagsterInstance
+from dagster._core.storage.pipeline_run import DagsterRun, PipelineRunStatus
+from dagster._core.system_config.objects import ResolvedRunConfig
+from dagster._core.utils import make_new_run_id
+from dagster._legacy import Materialization, ModeDefinition, PipelineDefinition, SolidDefinition
+from dagster._loggers import colored_console_logger
+from dagster._serdes import unpack_value
+from dagster._utils import EventGenerationManager, ensure_gen
+from dagster._utils.backcompat import deprecation_warning
 
 from .context import DagstermillExecutionContext, DagstermillRuntimeExecutionContext
 from .errors import DagstermillError
@@ -76,11 +78,10 @@ class Manager:
         resource_keys_to_init,
         instance,
         emit_persistent_events,
-        pipeline_def_for_backwards_compat,
     ):
         """
         Drop-in replacement for
-        `dagster.core.execution.resources_init.resource_initialization_manager`.  It uses a
+        `dagster._core.execution.resources_init.resource_initialization_manager`.  It uses a
         `DagstermillResourceEventGenerationManager` and explicitly calls `teardown` on it
         """
         generator = resource_initialization_event_generator(
@@ -92,7 +93,6 @@ class Manager:
             resource_keys_to_init=resource_keys_to_init,
             instance=instance,
             emit_persistent_events=emit_persistent_events,
-            pipeline_def_for_backwards_compat=pipeline_def_for_backwards_compat,
         )
         self.resource_manager = DagstermillResourceEventGenerationManager(
             generator, ScopedResourcesBuilder
@@ -188,16 +188,22 @@ class Manager:
 
         return self.context
 
-    def get_context(self, solid_config=None, mode_def=None, run_config=None):
+    def get_context(
+        self,
+        op_config: Any = None,
+        resource_defs: Optional[Mapping[str, ResourceDefinition]] = None,
+        logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
+        solid_config: Any = None,
+        mode_def: Optional[ModeDefinition] = None,
+        run_config: Optional[dict] = None,
+    ) -> DagstermillExecutionContext:
         """Get a dagstermill execution context for interactive exploration and development.
 
         Args:
-            solid_config (Optional[Any]): If specified, this value will be made available on the
-                context as its ``solid_config`` property.
-            mode_def (Optional[:class:`dagster.ModeDefinition`]): If specified, defines the mode to
-                use to construct the context. Specify this if you would like a context constructed
-                with specific ``resource_defs`` or ``logger_defs``. By default, an ephemeral mode
-                with a console logger will be constructed.
+            op_config (Optional[Any]): If specified, this value will be made available on the
+                context as its ``op_config`` property.
+            resource_defs (Optional[Mapping[str, ResourceDefinition]]): Specifies resources to provide to context.
+            logger_defs (Optional[Mapping[str, LoggerDefinition]]): Specifies loggers to provide to context.
             run_config(Optional[dict]): The config dict with which to construct
                 the context.
 
@@ -207,6 +213,35 @@ class Manager:
         check.opt_inst_param(mode_def, "mode_def", ModeDefinition)
         run_config = check.opt_dict_param(run_config, "run_config", key_type=str)
 
+        if solid_config and op_config:
+            raise DagsterInvariantViolationError(
+                "Attempted to provide both solid_config and op_config arguments to `dagstermill.get_context`. Please provide one or the other."
+            )
+
+        if resource_defs and mode_def:
+            raise DagsterInvariantViolationError(
+                "Attempted to provide both resource_defs and mode_def arguments to `dagstermill.get_context`. Please provide one or the other."
+            )
+
+        if logger_defs and mode_def:
+            raise DagsterInvariantViolationError(
+                "Attempted to provide both logger_defs and mode_def arguments to `dagstermill.get_context`. Please provide one or the other."
+            )
+
+        if solid_config:
+            deprecation_warning(
+                "solid_config argument to dagstermill.get_context",
+                "0.17.0",
+                "Use the op_config argument instead.",
+            )
+
+        if mode_def:
+            deprecation_warning(
+                "mode_def argument to dagstermill.get_context",
+                "0.17.0",
+                "Use the resource_defs argument to provide resources, and the logger_defs argument to provide loggers.",
+            )
+
         # If we are running non-interactively, and there is already a context reconstituted, return
         # that context rather than overwriting it.
         if self.context is not None and isinstance(
@@ -215,8 +250,12 @@ class Manager:
             return self.context
 
         if not mode_def:
-            mode_def = ModeDefinition(logger_defs={"dagstermill": colored_console_logger})
-            run_config["loggers"] = {"dagstermill": {}}
+            if not logger_defs:
+                logger_defs = {"dagstermill": colored_console_logger}
+                run_config["loggers"] = {"dagstermill": {}}
+            logger_defs = check.opt_mapping_param(logger_defs, "logger_defs")
+            resource_defs = check.opt_mapping_param(resource_defs, "resource_defs")
+            mode_def = ModeDefinition(logger_defs=logger_defs, resource_defs=resource_defs)
 
         solid_def = SolidDefinition(
             name="this_solid",
