@@ -1,11 +1,11 @@
-from dagster import seven
+from dagster import _seven
 
 PICKLE_PROTOCOL = 2
 
 
 def is_json_serializable(value):
     try:
-        seven.json.dumps(value)
+        _seven.json.dumps(value)
         return True
     except TypeError:
         return False
